@@ -2,7 +2,8 @@
 #'
 #' @usage occurrence(scientificname = NULL, taxonid = NULL, datasetid = NULL,
 #'   nodeid = NULL, areaid = NULL, startdate = NULL, enddate = NULL,
-#'   startdepth = NULL, enddepth = NULL, geometry = NULL, verbose = FALSE)
+#'   startdepth = NULL, enddepth = NULL, geometry = NULL, redlist = NULL,
+#'   verbose = FALSE)
 #' @param scientificname the scientific name.
 #' @param taxonid the taxon identifier (WoRMS AphiaID).
 #' @param datasetid the dataset identifier.
@@ -13,6 +14,7 @@
 #' @param startdepth the minimum depth below the sea surface.
 #' @param enddepth the maximum depth below the sea surface.
 #' @param geometry a WKT geometry string.
+#' @param redlist include only IUCN Red List species.
 #' @param verbose logical. Optional parameter to enable verbose logging (default = \code{FALSE}).
 #' @return The occurrence records.
 #' @examples
@@ -31,6 +33,7 @@ occurrence <- function(
   startdepth = NULL,
   enddepth = NULL,
   geometry = NULL,
+  redlist = NULL,
   verbose = FALSE
 ) {
 
@@ -53,6 +56,7 @@ occurrence <- function(
       startdepth = startdepth,
       enddepth = enddepth,
       geometry = geometry,
+      redlist = handle_logical(redlist),
       after = after,
       size = page_size()
     )
